Graph generators returning new cljgrapht.core graphs.
Graph generators returning new `cljgrapht.core` graphs.
(barabasi-albert-forest t n)(barabasi-albert-forest t n {:keys [seed]})A new Barabasi-Albert forest with t trees and n total vertices.
A new Barabasi-Albert forest with t trees and n total vertices.
(barabasi-albert-graph m0 m n)(barabasi-albert-graph m0 m n {:keys [seed directed?]})A new undirected Barabasi-Albert graph with initial m0, m, and total n.
A new undirected Barabasi-Albert graph with initial `m0`, `m`, and total `n`.
(complement-graph gr)(complement-graph gr {:keys [self-loops?]})A new complement of graph gr, optionally including missing self-loops.
A new complement of graph gr, optionally including missing self-loops.
(complete-bipartite-graph n1 n2)(complete-bipartite-graph n1 n2 {:keys [directed?]})A new undirected complete bipartite graph with partition sizes n1 and n2.
A new undirected complete bipartite graph with partition sizes n1 and n2.
(complete-graph n)(complete-graph n {:keys [directed?]})A new undirected complete graph with integer vertices 0..n-1.
A new undirected complete graph with integer vertices 0..n-1.
(directed-scale-free-graph alpha
gamma
delta-in
delta-out
target-edges
target-nodes)(directed-scale-free-graph alpha
gamma
delta-in
delta-out
target-edges
target-nodes
{:keys [seed multiple-edges? self-loops?]
:or {multiple-edges? true self-loops? true}})A new directed scale-free graph controlled by edge and vertex targets.
A new directed scale-free graph controlled by edge and vertex targets.
(empty-graph n)(empty-graph n {:keys [directed?]})A new undirected graph with n vertices and no edges.
A new undirected graph with n vertices and no edges.
(generalized-petersen-graph n k)(generalized-petersen-graph n k {:keys [directed?]})A new undirected generalized Petersen graph GP(n,k).
A new undirected generalized Petersen graph GP(n,k).
(gnm-random-bipartite-graph n1 n2 m)(gnm-random-bipartite-graph n1 n2 m {:keys [seed directed?]})A new random bipartite graph with partition sizes n1 and n2 and m edges.
A new random bipartite graph with partition sizes n1 and n2 and m edges.
(gnm-random-graph n m)(gnm-random-graph n m {:keys [seed directed? self-loops? multiple-edges?]})A new graph sampled uniformly from graphs with n vertices and m edges.
A new graph sampled uniformly from graphs with n vertices and m edges.
(gnp-random-bipartite-graph n1 n2 p)(gnp-random-bipartite-graph n1 n2 p {:keys [seed directed?]})A new random bipartite graph with partition sizes n1 and n2 and edge probability p.
A new random bipartite graph with partition sizes n1 and n2 and edge probability p.
(gnp-random-graph n p)(gnp-random-graph n p {:keys [seed directed? self-loops?]})A new undirected Erdos-Renyi G(n,p) graph.
A new undirected Erdos-Renyi G(n,p) graph.
(grid-graph rows cols)(grid-graph rows cols {:keys [directed?]})A new undirected rows-by-cols grid graph with integer vertices 0..n-1.
A new undirected rows-by-cols grid graph with integer vertices 0..n-1.
(hypercube-graph n)(hypercube-graph n {:keys [directed?]})A new undirected hypercube graph of dimension n.
A new undirected hypercube graph of dimension n.
(kleinberg-small-world-graph n p q r)(kleinberg-small-world-graph n p q r {:keys [seed directed?]})A new Kleinberg n-by-n lattice with local radius p and q long-range contacts.
A new Kleinberg n-by-n lattice with local radius p and q long-range contacts.
(linear-graph n)(linear-graph n {:keys [directed?]})A new undirected path graph with integer vertices 0..n-1.
A new undirected path graph with integer vertices 0..n-1.
(linearized-chord-diagram-graph n m)(linearized-chord-diagram-graph n m {:keys [seed]})A new linearized chord diagram multigraph with n vertices and m edges per vertex.
A new linearized chord diagram multigraph with n vertices and m edges per vertex.
(named-graph name)A new named graph selected from supported-named-graphs.
A new named graph selected from `supported-named-graphs`.
(planted-partition-graph l k p q)(planted-partition-graph l k p q {:keys [seed directed? self-loops?]})A new planted partition graph with l groups of k vertices.
A new planted partition graph with l groups of k vertices.
(prufer-tree n-or-sequence)(prufer-tree n {:keys [seed]})A new tree from a vertex count or an explicit Prüfer sequence.
A new tree from a vertex count or an explicit Prüfer sequence.
(random-regular-graph n d)(random-regular-graph n d {:keys [seed]})A new random d-regular graph with n vertices.
A new random d-regular graph with n vertices.
(ring-graph n)(ring-graph n {:keys [directed?]})A new undirected ring graph with integer vertices 0..n-1.
A new undirected ring graph with integer vertices 0..n-1.
(scale-free-graph n)(scale-free-graph n {:keys [seed directed?]})A new scale-free graph with n vertices.
A new scale-free graph with n vertices.
(star-graph n)(star-graph n {:keys [directed?]})A new undirected star graph with integer vertices 0..n-1.
A new undirected star graph with integer vertices 0..n-1.
Sorted set of keywords accepted by named-graph.
Sorted set of keywords accepted by `named-graph`.
(watts-strogatz-graph n k p)(watts-strogatz-graph n k p {:keys [seed directed? add-instead-of-rewire?]})A new undirected Watts-Strogatz graph with n vertices, degree k, and rewiring p.
A new undirected Watts-Strogatz graph with n vertices, degree k, and rewiring p.
(weighted-bipartite-matrix-graph n1 n2 weights)(weighted-bipartite-matrix-graph n1 n2 weights {:keys [directed?]})A new weighted bipartite graph from partition sizes and a weight matrix.
A new weighted bipartite graph from partition sizes and a weight matrix.
(weighted-matrix-graph weights)A new weighted digraph from a square adjacency weight matrix.
A new weighted digraph from a square adjacency weight matrix.
(wheel-graph n)(wheel-graph n {:keys [directed? inward-spokes?] :or {inward-spokes? true}})A new undirected wheel graph with n total vertices.
A new undirected wheel graph with n total vertices.
(windmill-graph mode m n)(windmill-graph mode m n {:keys [directed?]})A new windmill graph with m copies of K_n or C_n sharing one vertex.
A new windmill graph with m copies of K_n or C_n sharing one vertex.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |