cljgrapht.gen

Graph generators returning new cljgrapht.core graphs.

Graph generators returning new `cljgrapht.core` graphs.
raw docstring

barabasi-albert-graphclj

(barabasi-albert-graph m0 m n)
(barabasi-albert-graph m0 m n {:keys [seed]})

A new undirected Barabasi-Albert graph with initial m0, m, and total n.

A new undirected Barabasi-Albert graph with initial `m0`, `m`, and total `n`.
sourceraw docstring

complete-graphclj

(complete-graph n)

A new undirected complete graph with integer vertices 0..n-1.

A new undirected complete graph with integer vertices 0..n-1.
sourceraw docstring

gnp-random-graphclj

(gnp-random-graph n p)
(gnp-random-graph n p {:keys [seed]})

A new undirected Erdos-Renyi G(n,p) graph.

A new undirected Erdos-Renyi G(n,p) graph.
sourceraw docstring

grid-graphclj

(grid-graph rows cols)

A new undirected rows-by-cols grid graph with integer vertices 0..n-1.

A new undirected rows-by-cols grid graph with integer vertices 0..n-1.
sourceraw docstring

ring-graphclj

(ring-graph n)

A new undirected ring graph with integer vertices 0..n-1.

A new undirected ring graph with integer vertices 0..n-1.
sourceraw docstring

star-graphclj

(star-graph n)

A new undirected star graph with integer vertices 0..n-1.

A new undirected star graph with integer vertices 0..n-1.
sourceraw docstring

watts-strogatz-graphclj

(watts-strogatz-graph n k p)
(watts-strogatz-graph n k p {:keys [seed]})

A new undirected Watts-Strogatz graph with n vertices, degree k, and rewiring p.

A new undirected Watts-Strogatz graph with n vertices, degree k, and rewiring p.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries