Loom protocol interop for raw JGraphT graphs.
This namespace needs a loom artifact (net.clojars.savya/loom or aysylu/loom) on the classpath. cljgrapht does not include it as a dependency.
EditableGraph operations mutate the underlying JGraphT graph in place and return the same instance. The return values from the add and remove operations are the same graph, not new copies. Loom's persistent graph records behave differently.
Loom protocol interop for raw JGraphT graphs. This namespace needs a loom artifact (net.clojars.savya/loom or aysylu/loom) on the classpath. cljgrapht does not include it as a dependency. EditableGraph operations mutate the underlying JGraphT graph in place and return the same instance. The return values from the add and remove operations are the same graph, not new copies. Loom's persistent graph records behave differently.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |