Loom protocol interop for raw JGraphT graphs.
Requires a loom artifact (net.clojars.savya/loom or aysylu/loom) on the classpath; cljgrapht does not drag it in.
EditableGraph operations mutate the underlying JGraphT graph in place and return the same instance. Unlike loom's persistent graph records, return values from add/remove operations are not fresh copies.
Loom protocol interop for raw JGraphT graphs. Requires a loom artifact (net.clojars.savya/loom or aysylu/loom) on the classpath; cljgrapht does not drag it in. EditableGraph operations mutate the underlying JGraphT graph in place and return the same instance. Unlike loom's persistent graph records, return values from add/remove operations are not fresh copies.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |